@@ -8,9 +8,9 @@
 #' @param dataset a character string specifying the dataset within the mart to
 #'  be used, e.g. \code{dataset} = \code{"hsapiens_gene_ensembl"}.
 #' @param attributes a character vector specifying the attributes that shall be
-#'  used, e.g. \code{attributes} = 
+#'  used, e.g. \code{attributes} =
 #'  \code{c("start_position","end_position","description")}.
-#' @param filters a character vector specifying the filter (query key) for the 
+#' @param filters a character vector specifying the filter (query key) for the
 #' BioMart query, e.g. \code{filter} = \code{"ensembl_gene_id"}.
 #' @param ... additional parameters for the
 #'  \code{\link[biomaRt]{getBM}} function.
@@ -18,7 +18,7 @@
 #' @author Hajk-Georg Drost
 #' @details This function is the main query function of the biomartr package.
 #'
-#' It enables to fastly access annotations of a given gene set based 
+#' It enables to fastly access annotations of a given gene set based
 #' on the \pkg{biomaRt} package
 #' implemented by Steffen Durinck et al.
 #'
@@ -46,12 +46,11 @@
 #'         filters    = "ensembl_gene_id")
 #'}
 #'
-#' @return A data.table storing the initial query gene vector in 
+#' @return A data.table storing the initial query gene vector in
 #' the first column, the output
 #' gene vector in the second column, and all attributes in
 #' the following columns.
-#' @seealso \code{\link{organismFilters}}, \code{\link{organismBM}},
-#' \code{\link[biomaRt]{listAttributes}}, \code{\link[biomaRt]{getBM}}
+#' @family biomaRt
 #' @import biomaRt
 #' @export
 biomart <- function(genes,
@@ -61,51 +60,34 @@ biomart <- function(genes,
                     filters,
                     mute_citation = FALSE,
                     ...) {
-        
+
         message("Starting BioMart query ...")
-        
-    if (stringr::str_detect(mart, "ENSEMBL"))
-        # connect to BioMart API
-        m <- biomaRt::useMart(mart, host = "https://www.ensembl.org")
-    
-    if (stringr::str_detect(mart, "plants"))
-        # connect to BioMart API
-        m <- biomaRt::useMart(mart, host = "https://plants.ensembl.org")
-    
-    if (stringr::str_detect(mart, "fung"))
-        # connect to BioMart API
-        m <- biomaRt::useMart(mart, host = "https://fungi.ensembl.org")
-    
-    if (stringr::str_detect(mart, "protist"))
-        # connect to BioMart API
-        m <- biomaRt::useMart(mart, host = "https://protist.ensembl.org")
-    
-    if (stringr::str_detect(mart, "metazoa"))
-        # connect to BioMart API
-        m <- biomaRt::useMart(mart, host = "https://metazoa.ensembl.org")
-    
-    d <- biomaRt::useDataset(dataset = dataset, mart = m)
-    
-    # establishing a biomaRt connection and retrieving the 
-    # information for the given gene list
-    query <-
-        biomaRt::getBM(
-            attributes = as.character(c(filters, attributes)),
-            filters    = as.character(filters),
-            values     = as.character(genes),
-            mart       = d,
-            ...
-        )
-    
-    colnames(query) <- c(filters, attributes)
-    
-    genes <- tibble::tibble(as.character(genes))
-    colnames(genes) <- as.character(filters)
-    
-    tbl_biomart <-
-        merge(query, genes, by = filters, incomparables = NA)
-    
-    please_cite_biomartr(mute_citation = mute_citation)
-    return(tbl_biomart)
-    
+  # connect to BioMart API
+  host_url <- biomart_base_urls_select(mart)
+  m <- m <- biomaRt::useMart(mart, host = host_url)
+
+  d <- biomaRt::useDataset(dataset = dataset, mart = m)
+
+  # establishing a biomaRt connection and retrieving the
+  # information for the given gene list
+  query <-
+      biomaRt::getBM(
+          attributes = as.character(c(filters, attributes)),
+          filters    = as.character(filters),
+          values     = as.character(genes),
+          mart       = d,
+          ...
+      )
+
+  colnames(query) <- c(filters, attributes)
+
+  genes <- tibble::tibble(as.character(genes))
+  colnames(genes) <- as.character(filters)
+
+  tbl_biomart <-
+      merge(query, genes, by = filters, incomparables = NA)
+
+  please_cite_biomartr(mute_citation = mute_citation)
+  return(tbl_biomart)
+
 }
