@@ -29,11 +29,8 @@ getGenome <- function(db = "refseq",
                 'genbank', or 'ensembl'.",
                 call. = FALSE
             )
-        if (!(assembly_type %in% c("toplevel", "primary_assembly")))
-            stop("Please select one the available assembly types: \ntoplevel, primary_assembly")
-        if ((db != "ensembl") && (assembly_type != "toplevel"))
-            stop( "The assembly_type argument is not default value.",
-            "Don't change this argument when not using db = 'ensembl'.", call. = FALSE)
+        if (!all(assembly_type %in% c("toplevel", "primary_assembly")))
+            stop("Please specify valid assembly types: \ntoplevel, primary_assembly")
 
         if (!is.logical(reference))
             stop("Please specify 'reference' as either TRUE or FALSE.", call. = FALSE)
